package com.cardiff.client_project.controller.admin;

import com.cardiff.client_project.pojo.dto.HospitalDTO;
import com.cardiff.client_project.pojo.vo.NurseVO;
import com.cardiff.client_project.service.CommonAdminHospitalService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/commonAdmin/hospital")
public class CommonAdminHospitalController {

    @Autowired
    private CommonAdminHospitalService commonAdminHospitalService;

    @GetMapping("/all")
    public List<HospitalDTO> getAllHospitals(@RequestParam(value = "name", required = false) String name,
                                             @RequestParam(value = "location", required = false) String location) {
        if (name == null && location == null) {
            return commonAdminHospitalService.getAllHospitals();
        }
        return commonAdminHospitalService.searchHospitals(name, location);
    }

    @PostMapping("/add")
    public ResponseEntity<String> addHospital(@RequestBody HospitalDTO hospital) {
        try {
            commonAdminHospitalService.addHospital(hospital);
            return ResponseEntity.ok("Hospital added successfully!");
        } catch (Exception e) {
            e.printStackTrace(); // Print error log
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR)
                    .body("Error adding hospital: " + e.getMessage());
        }
    }

    @GetMapping("/currentUser")
    public ResponseEntity<String> getCurrentUser() {
        String username = "admin";
        return ResponseEntity.ok(username);
    }

    @PutMapping("/update")
    public ResponseEntity<String> updateHospital(@RequestBody HospitalDTO hospital) {
        commonAdminHospitalService.updateHospital(hospital);
        return ResponseEntity.ok("Hospital updated successfully!");
    }

    @DeleteMapping("/delete/{id}")
    public ResponseEntity<String> deleteHospital(@PathVariable int id) {
        try {
            commonAdminHospitalService.deleteHospital(id);
            commonAdminHospitalService.resetHospitalIds(); // Reset IDs after deletion
            return ResponseEntity.ok("Hospital deleted successfully!");
        } catch (Exception e) {
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR)
                    .body("Failed to delete hospital: " + e.getMessage());
        }
    }


    @GetMapping("/nurses")
    public List<NurseVO> getNurses(@RequestParam(value = "name", required = false) String name,
                                   @RequestParam(value = "hospitalId", required = false) Integer hospitalId) {
        if (name == null && hospitalId == null) {
            return commonAdminHospitalService.getAllNurses();
        }
        return commonAdminHospitalService.searchNurses(name, hospitalId);
    }

    @GetMapping("/{id}")
    public ResponseEntity<HospitalDTO> getHospitalById(@PathVariable int id) {
        HospitalDTO hospital = commonAdminHospitalService.getHospitalById(id);
        if (hospital != null) {
            return ResponseEntity.ok(hospital);
        } else {
            return ResponseEntity.status(HttpStatus.NOT_FOUND)
                    .body(null);
        }
    }


}
