package com.cardiff.client_project.mapper;

import com.cardiff.client_project.constant.ResponseCode;
import com.cardiff.client_project.pojo.entity.Nurse;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.simple.SimpleJdbcInsert;
import org.springframework.stereotype.Repository;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Repository
public class NurseMapper {
    @Autowired
    JdbcTemplate jdbcTemplate;
    /**
     * update nurse data
     * @param nurse
     * @return
     */
    public int update(Nurse nurse) {
        String sql = "UPDATE nurse SET name = ?,phone = ?, age=?, email=?, address=?, status = ?,hospitalId =? WHERE id = ?";
        int update = jdbcTemplate.update(sql, preparedStatement -> {
            preparedStatement.setString(1, nurse.getName());
            preparedStatement.setString(2, nurse.getPhone());
            preparedStatement.setInt(3, nurse.getAge());
            preparedStatement.setString(4, nurse.getEmail());
            preparedStatement.setString(5, nurse.getAddress());
            preparedStatement.setInt(6, nurse.getStatus());
            preparedStatement.setInt(7, nurse.getHospitalId());
            preparedStatement.setInt(8, nurse.getId());
        });
        return update;
    }


    /**
     * select nurse
     * @return
     */
    public List<Nurse> selectAllNurse(int hospitalId){

        // Parameterized queries avoid SQL injection
        String sql = "SELECT * FROM nurse where hospitalId=?";
        List<Nurse> query = jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(Nurse.class), hospitalId);
        System.out.println(query);
        return query;
    }


    /**
     * fuzzy query
     * @param nurse
     * @return
     */
    public List<Nurse> selectByItem(Nurse nurse) {
        System.out.println("test:" + nurse);
        // Build the basic SQL and parameter list
        StringBuilder sql = new StringBuilder("SELECT * FROM nurse");

        //Dynamic table name stitching
        sql.append(" WHERE 1=1 ");
        List<Object> params = new ArrayList<>();

        //Dynamic concatenation of query conditions
        if (nurse.getName() != null && nurse.getName() != "") {
            sql.append(" AND name LIKE ?");
            params.add("%" + nurse.getName() + "%");
        }
        if (nurse.getPhone() != null && nurse.getPhone() != "") {
            sql.append(" AND phone LIKE ?");
            params.add("%" + nurse.getPhone() + "%");
        }
        if (nurse.getAddress() != null && nurse.getAddress() != "") {
            sql.append(" AND address LIKE ?");
            params.add("%" + nurse.getAddress() + "%");
        }
        if (Integer.valueOf(nurse.getStatus()) != null) {
            sql.append(" AND status = ?, ");
            params.add(nurse.getStatus());
        }
        sql.setLength(sql.length() - 2);

        System.out.println("sql: "+sql.toString());
        List<Nurse> query = jdbcTemplate.query(sql.toString(), params.toArray(), new BeanPropertyRowMapper<>(Nurse.class));
        System.out.println("query" + query);
        return query;

    }

    /**
     * Query data by name
     * @param name
     * @return
     */
    public Object getNurseByName(String name){
        try {
            //Query nurse table
            String sql = "select * from nurse where name=?";
            return jdbcTemplate.queryForObject(sql, new Object[]{name}, new BeanPropertyRowMapper<>(Nurse.class));
        } catch (Exception e) {
            e.printStackTrace();
        }
        // If all queries are null, return null
        return null;
    }

    /**
     * Get role permissions based on id
     * @param roleId
     * @return
     */
    public String getTypeById(int roleId) {
        String sql="SELECT type from role where roleId=?;";
        String type= jdbcTemplate.queryForObject(sql, new Object[]{roleId}, String.class);
        return type;
    }

    /**
     * insert nurse
     * @param nurse
     */
    public Result insertNurseInform(Nurse nurse) {
        //Check whether the account exists(If the name and email address are the same, the account is confirmed to exist)
        String sql = "SELECT count(id) FROM nurse where name = ? and email = ?";
        Integer count= jdbcTemplate.queryForObject(sql, new Object[]{nurse.getName(), nurse.getEmail()}, Integer.class);
        System.out.println(count);
        if(count > 0){
            return Result.error(ResponseCode.ACCOUNT_EXISTS_ERROR);
        }

        //insert data
        SimpleJdbcInsert insert = new SimpleJdbcInsert(jdbcTemplate)
                .withTableName("nurse")
                .usingGeneratedKeyColumns("id");

        Map<String, Object> parameters = new HashMap<>();
        parameters.put("Id",nurse.getId());
        parameters.put("hospitalId",nurse.getHospitalId());
        parameters.put("name",nurse.getName());
        parameters.put("age", nurse.getAge());
        parameters.put("phone",nurse.getPhone());
        parameters.put("email",nurse.getEmail());
        parameters.put("address", nurse.getAddress());
        parameters.put("status",nurse.getStatus());

        Number number = insert.executeAndReturnKey(parameters);
        if(number.longValue() > 0){
            return Result.success(ResponseCode.SUCCESS);
        }else {
            return Result.error(ResponseCode.ERROR);
        }
    }

    /**
     * Batch deletion based on id
     * @param ids
     * @return
     */
    public int[] deleteByIdAndType(List<Integer> ids, String type) {
        String sql = "DELETE FROM nurse WHERE id=?";
        String sql_1="ALTER TABLE nurse DROP COLUMN id;";
        String sql_2="ALTER TABLE nurse ADD COLUMN id INT NOT NULL PRIMARY KEY AUTO_INCREMENT FIRST;";

        List<Object[]> idList = new ArrayList<>();
        // Build parameter list
        for (Integer id : ids) {
            idList.add(new Object[]{id});
        }
        // Batch delete
        int[] item = jdbcTemplate.batchUpdate(sql, idList);
        jdbcTemplate.update(sql_1);
        jdbcTemplate.update(sql_2);
        return item;
    }

}
