package com.cardiff.client_project.mapper;

import com.cardiff.client_project.pojo.dto.HospitalDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

@Repository
public class NursingHomeMapper {

    @Autowired
    private JdbcTemplate jdbcTemplate;

    public List<HospitalDTO> searchHospitals(String name) {
        String sql = """
            SELECT 
                id, name, address, phone, maxAmount, 
                amountPatient, status, approval_status
            FROM hospital 
            WHERE status = 1 
            AND name LIKE CONCAT('%', ?, '%')
            ORDER BY name ASC
        """;

        return jdbcTemplate.query(sql, 
            ps -> ps.setString(1, name),
            this::mapToDTO);
    }

    public List<HospitalDTO> findAllNursingHomes() {
        String sql = """
            SELECT 
                id, name, address, phone, maxAmount,
                amountPatient, status, approval_status
            FROM hospital 
            WHERE status = 1
        """;

        return jdbcTemplate.query(sql, this::mapToDTO);
    }

    public List<HospitalDTO> getPendingApprovals() {
        String sql = """
            SELECT 
                id, name, address, phone, maxAmount,
                amountPatient, status, approval_status
            FROM hospital 
            WHERE approval_status = 'PENDING'
        """;

        return jdbcTemplate.query(sql, this::mapToDTO);
    }

    public int updateApprovalStatus(int id, String status) {
        String sql = "UPDATE hospital SET approval_status = ? WHERE id = ?";
        return jdbcTemplate.update(sql, status, id);
    }

    private HospitalDTO mapToDTO(ResultSet rs, int rowNum) throws SQLException {
        HospitalDTO dto = new HospitalDTO();
        dto.setId(rs.getInt("id"));
        dto.setName(rs.getString("name"));
        dto.setLocation(rs.getString("address"));
        dto.setPhone(rs.getString("phone"));
        int maxAmount = rs.getInt("maxAmount");
        int amountPatient = rs.getInt("amountPatient");
        dto.setTotalBeds(maxAmount);
        dto.setAvailableBeds(maxAmount - amountPatient);
        dto.setOccupancyRate(calculateOccupancy(maxAmount, amountPatient));
        dto.setApprovalStatus(rs.getString("approval_status"));
        return dto;
    }

    private double calculateOccupancy(int maxAmount, int amountPatient) {
        return maxAmount > 0 ? ((double) amountPatient / maxAmount) * 100 : 0;
    }

    public int insertHospital(HospitalDTO dto) {
        String sql = """
            INSERT INTO hospital (
                name, address, phone, maxAmount, 
                amountPatient, status, type, roleId,
                approval_status
            ) VALUES (?, ?, ?, ?, ?, 1, 'hospital', 3, 'PENDING')
        """;

        return jdbcTemplate.update(sql,
            dto.getName(),
            dto.getLocation(),
            dto.getPhone(),
            dto.getTotalBeds(),
            dto.getTotalBeds() - dto.getAvailableBeds()
        );
    }

    public int updateHospital(HospitalDTO dto) {
        String sql = """
            UPDATE hospital 
            SET 
                name = ?,
                address = ?,
                phone = ?,
                maxAmount = ?,
                amountPatient = ?
            WHERE id = ? AND status = 1
        """;

        return jdbcTemplate.update(sql,
            dto.getName(),
            dto.getLocation(),
            dto.getPhone(),
            dto.getTotalBeds(),
            dto.getTotalBeds() - dto.getAvailableBeds(),
            dto.getId()
        );
    }

    public int[] deleteHospitalByIds(List<Integer> ids) {
        String sql = "UPDATE hospital SET status = 0 WHERE id = ?";
        List<Object[]> params = ids.stream()
            .map(id -> new Object[]{id})
            .toList();
        return jdbcTemplate.batchUpdate(sql, params);
    }

    public int updateBedCount(int hospitalId, int currentPatients) {
        String sql = """
            UPDATE hospital 
            SET amountPatient = ?
            WHERE id = ? AND maxAmount >= ? AND status = 1
        """;
        return jdbcTemplate.update(sql, currentPatients, hospitalId, currentPatients);
    }
}