package com.cardiff.client_project.utils;

import com.cardiff.client_project.constant.ResponseCode;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.io.Serializable;

/**
 * Return data class
 * @JsonInclude Guarantee that when serializing json, if it is a null object, the key will also disappear
 * @param <T>
 */

@JsonInclude(JsonInclude.Include.NON_NULL)
public class Result<T> implements Serializable {
   // private static final long serialVersionUID = 7735505903525411467L;//Serialization identifier

    // Success value. The default value is 1
    private static final int SUCCESS_CODE = 1;
    // Failure value, the default is 0
    private static final int ERROR_CODE = 0;

    //Status code
    private int code;
    //message
    private String msg;
    //data
    private T data;

    private Result(int code){
        this.code = code;
    }
    private Result(int code, T data){
        this.code = code;
        this.data = data;
    }
    public Result(int code, String msg){
        this.code = code;
        this.msg = msg;
    }
    private Result(int code, String msg, T data){
        this.code = code;
        this.msg = msg;
        this.data = data;
    }

    public static <T> Result<T> success(){
        return new Result<T>(SUCCESS_CODE,"success");
    }
    public static <T> Result<T> success(String msg){
        return new Result<T>(SUCCESS_CODE,msg);
    }
    public static <T> Result<T> success(T data){
        return new Result<T>(SUCCESS_CODE,data);
    }
    public static <T> Result<T> success(String msg, T data){
        return new Result<T>(SUCCESS_CODE,msg,data);
    }

    public static <T> Result<T> error(){
        return new Result<T>(ERROR_CODE,"error");
    }
    public static <T> Result<T> error(String msg){
        return new Result<T>(ERROR_CODE,msg);
    }
    public static <T> Result<T> error(int code, String msg){
        return new Result<T>(code,msg);
    }
    public static <T> Result<T> error(ResponseCode res){
        return new Result<T>(res.getCode(),res.getMessage());
    }

    public int getCode(){
        return code;
    }
    public String getMsg(){
        return msg;
    }
    public T getData(){
        return data;
    }
}