$(document).ready(function() {
    const API_BASE_URL = '/api/hospitals';
    
    // Initialize
    loadPendingHospitals();
    setupNavigation();

    function setupNavigation() {
        const nav = `
            <nav class="top-nav">
                <div class="nav-brand">Digital Insight for Health</div>
                <div class="nav-items">
                    <a href="/superAdminView.html?type=hospital" class="nav-link">
                        <i class="fas fa-home"></i> Dashboard
                    </a>
                    <a href="/beds.html" class="nav-link">
                        <i class="fas fa-bed"></i> Beds
                    </a>
                    <a href="/approvalSystem.html" class="nav-link active">
                        <i class="fas fa-check-circle"></i> Approvals
                    </a>
                    <button class="nav-link sign-out" onclick="handleSignOut()">
                        <i class="fas fa-sign-out-alt"></i> Sign Out
                    </button>
                </div>
                <div class="user-info">
                    <span class="user-name">${localStorage.getItem('name') || 'User'}</span>
                    <span class="user-role">${localStorage.getItem('type') || 'Guest'}</span>
                </div>
            </nav>
        `;
        $('.main-container').prepend(nav);
    }

    function loadPendingHospitals() {
        $.ajax({
            url: `${API_BASE_URL}/pending`,
            method: 'GET',
            success: function(response) {
                if (response.code === 1) {
                    displayPendingHospitals(response.data);
                } else {
                    showMessage('warning', 'No pending hospitals found');
                }
            },
            error: handleError
        });
    }

    function displayPendingHospitals(hospitals) {
        const tbody = $('#pendingTableBody');
        tbody.empty();

        if (!hospitals || hospitals.length === 0) {
            tbody.append(`
                <tr>
                    <td colspan="7" class="text-center">No pending hospitals found</td>
                </tr>
            `);
            return;
        }

        hospitals.forEach(hospital => {
            const tr = `
                <tr>
                    <td>${hospital.name}</td>
                    <td>${hospital.location}</td>
                    <td>${hospital.phone}</td>
                    <td>${hospital.totalBeds}</td>
                    <td>${hospital.availableBeds}</td>
                    <td>
                        <span class="status-badge pending">PENDING</span>
                    </td>
                    <td>
                        <button class="btn btn-success approve-btn" onclick="handleApproval(${hospital.id}, 'APPROVED')">
                            <i class="fas fa-check"></i> Approve
                        </button>
                        <button class="btn btn-danger reject-btn" onclick="handleApproval(${hospital.id}, 'REJECTED')">
                            <i class="fas fa-times"></i> Reject
                        </button>
                    </td>
                </tr>
            `;
            tbody.append(tr);
        });
    }

    window.handleApproval = function(hospitalId, status) {
        if (!confirm(`Are you sure you want to ${status.toLowerCase()} this hospital?`)) {
            return;
        }

        $.ajax({
            url: `${API_BASE_URL}/${hospitalId}/approval`,
            method: 'PUT',
            data: { status: status },
            success: function(response) {
                if (response.code === 1) {
                    showMessage('success', `Hospital ${status.toLowerCase()} successfully`);
                    loadPendingHospitals();
                } else {
                    showMessage('error', response.msg || 'Operation failed');
                }
            },
            error: handleError
        });
    }

    function showMessage(type, message) {
        const alertDiv = `
            <div class="alert alert-${type} alert-dismissible fade show">
                ${message}
                <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
            </div>
        `;
        
        $('.messages').html(alertDiv);
        setTimeout(() => {
            $('.alert').fadeOut().remove();
        }, 3000);
    }

    function handleError(xhr, status, error) {
        console.error('API Error:', error);
        showMessage('error', 'An error occurred. Please try again.');
    }
});

function handleSignOut() {
    localStorage.clear();
    window.location.href = '/login.html';
}